# PySDL3
PySDL3 is a pure Python wrapper around the SDL3 library.

## Getting Started
Just run one of the following commands in a terminal:
```
# To install the latest stable version from PyPi:
pip install --upgrade PySDL3

# To install the latest development version from GitHub:
pip install --upgrade git+https://github.com/Aermoss/PySDL3.git
```

## Requirements
Pre-built binaries are provided within the module so there are no additional requirements.

## Documentation
There is no documentation available for now, but the function definitions are exactly the same as the SDL3 function definitions, so you can use the documentation of SDL3.